@@ -1706,9 +1706,10 @@ def interpreter_run(name: TestName,
 
     # check the exit code
     if exit_code != getTestOpts().exit_code:
-        print('Wrong exit code for ' + name + '(' + way + ') (expected', getTestOpts().exit_code, ', actual', exit_code, ')')
-        dump_stdout(name)
-        dump_stderr(name)
+        if config.verbose >= 1 and _expect_pass(way):
+            print('Wrong exit code for ' + name + '(' + way + ') (expected', getTestOpts().exit_code, ', actual', exit_code, ')')
+            dump_stdout(name)
+            dump_stderr(name)
         return failBecause('bad exit code (%d)' % exit_code,
                            stderr=read_stderr(name),
                            stdout=read_stdout(name))
@@ -1770,7 +1771,11 @@ def stdout_ok(name: TestName, way: WayName) -> bool:
                           expected_stdout_file, actual_stdout_file)
 
 def read_stdout( name: TestName ) -> str:
-    return in_testdir(name, 'run.stdout').read_text(encoding='UTF-8')
+    path = in_testdir(name, 'run.stdout')
+    if path.exists():
+        return path.read_text(encoding='UTF-8')
+    else:
+        return ''
 
 def dump_stdout( name: TestName ) -> None:
     str = read_stdout(name).strip()
@@ -1788,7 +1793,11 @@ def stderr_ok(name: TestName, way: WayName) -> bool:
                           whitespace_normaliser=normalise_whitespace)
 
 def read_stderr( name: TestName ) -> str:
-    return in_testdir(name, 'run.stderr').read_text(encoding='UTF-8')
+    path = in_testdir(name, 'run.stderr')
+    if path.exists():
+        return path.read_text(encoding='UTF-8')
+    else:
+        return ''
 
 def dump_stderr( name: TestName ) -> None:
     str = read_stderr(name).strip()
@@ -2124,9 +2133,16 @@ def normalise_errmsg(s: str) -> str:
     # and not understood by older binutils (ar, ranlib, ...)
     s = modify_lines(s, lambda l: re.sub('^(.+)warning: (.+): unsupported GNU_PROPERTY_TYPE \(5\) type: 0xc000000(.*)$', '', l))
 
-    # filter out nix garbage, that just keeps on showing up as errors on darwin
-    s = modify_lines(s, lambda l: re.sub('^(.+)\.dylib, ignoring unexpected dylib file$','', l))
-
+    s = re.sub('ld: warning: passed .* min versions \(.*\) for platform macOS. Using [\.0-9]+.','',s)
+    s = re.sub('ld: warning: -sdk_version and -platform_version are not compatible, ignoring -sdk_version','',s)
+    # ignore superfluous dylibs passed to the linker.
+    s = re.sub('ld: warning: .*, ignoring unexpected dylib file\n','',s)
+    # ignore LLVM Version mismatch garbage; this will just break tests.
+    s = re.sub('You are using an unsupported version of LLVM!.*\n','',s)
+    s = re.sub('Currently only [\.0-9]+ is supported. System LLVM version: [\.0-9]+.*\n','',s)
+    s = re.sub('We will try though\.\.\..*\n','',s)
+    # ignore warning about strip invalidating signatures
+    s = re.sub('.*strip: changes being made to the file will invalidate the code signature in.*\n','',s)
     return s
 
 # normalise a .prof file, so that we can reasonably compare it against
@@ -2200,6 +2216,17 @@ def normalise_output( s: str ) -> str:
     # ghci outputs are pretty unstable with -fexternal-dynamic-refs, which is
     # requires for -fPIC
     s = re.sub('  -fexternal-dynamic-refs\n','',s)
+    s = re.sub('ld: warning: passed .* min versions \(.*\) for platform macOS. Using [\.0-9]+.','',s)
+    s = re.sub('ld: warning: -sdk_version and -platform_version are not compatible, ignoring -sdk_version','',s)
+    # ignore superfluous dylibs passed to the linker.
+    s = re.sub('ld: warning: .*, ignoring unexpected dylib file\n','',s)
+    # ignore LLVM Version mismatch garbage; this will just break tests.
+    s = re.sub('You are using an unsupported version of LLVM!.*\n','',s)
+    s = re.sub('Currently only [\.0-9]+ is supported. System LLVM version: [\.0-9]+.*\n','',s)
+    s = re.sub('We will try though\.\.\..*\n','',s)
+    # ignore warning about strip invalidating signatures
+    s = re.sub('.*strip: changes being made to the file will invalidate the code signature in.*\n','',s)
+
     return s
 
 def normalise_asm( s: str ) -> str:
