@@ -2,6 +2,8 @@
 #include "conc059_stub.h"
 #include <unistd.h>
 #include <stdio.h>
+// stdlib is needed for exit()
+#include <stdlib.h>
 #if mingw32_HOST_OS
 #include <windows.h>
 #endif
